@@ -5,6 +5,7 @@ from tiddlyweb.model.policy import UserRequiredError, ForbiddenError
 from tiddlyweb.serializer import NoSerializationError
 from tiddlyweb.web.http import HTTP415
 
+
 def list_entities(environ, start_response, mime_type, store_list,
         serializer_list):
     """
@@ -29,4 +30,7 @@ def list_entities(environ, start_response, mime_type, store_list,
     except NoSerializationError:
         raise HTTP415('Content type not supported: %s' % mime_type)
 
-    return output
+    if isinstance(output, basestring):
+        return [output]
+    else:
+        return output
